SalientPoleMachine

Struct SalientPoleMachine 

pub struct SalientPoleMachine {
Show 18 fields pub metadata: Metadata, pub r: f64, pub td0_p: f64, pub td0_pp: f64, pub tq0_pp: f64, pub xd: f64, pub xq: f64, pub xd_p: f64, pub xd_pp: f64, pub xl: f64, pub se: (f64, f64), pub ext: Value, pub γ_d1: f64, pub γ_q1: f64, pub γ_d2: f64, pub states: Vec<String>, pub n_states: usize, pub internal: InfrastructureSystemsInternal,
}
Parameters of 3-states salient-pole synchronous machine with quadratic/exponential saturation: IEEE Std 1110 5.3.1 (Model 2.1). GENSAL or GENSAE model in PSSE and PSLF.

Fields

metadata: Metadatar: f64

Armature resistance

td0_p: f64

Time constant of transient d-axis voltage

td0_pp: f64

Time constant of sub-transient d-axis voltage

tq0_pp: f64

Time constant of sub-transient q-axis voltage

xd: f64

Reactance after EMF in d-axis per unit

xq: f64

Reactance after EMF in q-axis per unit

xd_p: f64

Transient reactance after EMF in d-axis per unit

xd_pp: f64

Sub-Transient reactance after EMF in d-axis per unit. Note: Xd_pp = Xq_pp

xl: f64

Stator leakage reactance

se: (f64, f64)

Saturation factor at 1 and 1.2 pu flux: Se(eq_p) = B(eq_p-A)^2

ext: Valueγ_d1: f64

γ_d1 parameter

γ_q1: f64

γ_q1 parameter

γ_d2: f64

γ_d2 parameter

states: Vec<String>

The states are: eq_p: q-axis generator voltage behind the transient reactance, ψ_kd: flux linkage in the first equivalent damping circuit in the d-axis, ψq_pp: phasonf of the subtransient flux linkage in the q-axis

n_states: usize

SalientPoleMachine has 3 states

internal: InfrastructureSystemsInternal

power system internal reference, do not modify

Implementations

Source

impl SalientPoleMachine

pub const SUPER_TYPE: &'static str = "Machine"