pub struct StaticReserve {
pub metadata: Metadata,
pub name: String,
pub available: bool,
pub time_frame: f64,
pub requirement: f64,
pub ext: Value,
pub internal: InfrastructureSystemsInternal,
}Expand description
Data Structure for a proportional reserve product for system simulations.
Fields
metadata: Metadataname: Stringavailable: booltime_frame: f64the relative saturation time_frame
requirement: f64the static value of required reserves in system p.u.
ext: Valueinternal: InfrastructureSystemsInternalpower system internal reference, do not modify
Implementations
Sourceimpl StaticReserve
impl StaticReserve
pub const SUPER_TYPE: &'static str = "Reserve{T}"